==> YNQ-1.5.2_Linux_S_CP.zip: YNQ-1.5.2_Linux_S_CP/NQ Library Reference/html/group__mount__info.js <==
var group__mount__info =
[
    [ "User logon type", "group__user__logon__type.html", "group__user__logon__type" ],
    [ "Server capabilities", "group__server__capabilities.html", "group__server__capabilities" ],
    [ "signing policy", "group__signing__policy.html", "group__signing__policy" ],
    [ "CCSStatistics", "structCCSStatistics.html", [
      [ "readAmount", "structCCSStatistics.html#aa6cd342446ae008b9e087a597ebafcd1", null ],
      [ "writeAmount", "structCCSStatistics.html#ae4f3e5f90cd4f5a4f78ef5f580f92c88", null ]
    ] ],
    [ "CCServerInfo", "structCCServerInfo.html", [
      [ "dialect", "structCCServerInfo.html#a0c6ea5c14c29944549e8dd222ee6412f", null ],
      [ "serverCapabilities", "structCCServerInfo.html#a12f4460a27c3e80924010b0c35de7bb7", null ],
      [ "ips", "structCCServerInfo.html#a99d713ac4500832a73f75bda8adfdbbc", null ],
      [ "numIps", "structCCServerInfo.html#adb11fee1ed0404b98451150dd0ef3da7", null ],
      [ "serverSigningPolicy", "structCCServerInfo.html#a482566f1f1569ff421052c8cdf831b71", null ]
    ] ],
    [ "CCMountInfoA", "structCCMountInfoA.html", [
      [ "creationTime", "structCCMountInfoA.html#ae3c19055292a905bbdf5133f09fe290c", null ],
      [ "userLogonType", "structCCMountInfoA.html#a2bfd1f0697d185286fa83063a782e5c6", null ],
      [ "serverName", "structCCMountInfoA.html#afe53a55e1d20c7df2b78eda275d16b5e", null ],
      [ "serverInfo", "structCCMountInfoA.html#a3d9999f6066e144079ecb9002ffa662b", null ],
      [ "statistics", "structCCMountInfoA.html#a79c8956fdd6940e32fe0bfa07a67c8fa", null ]
    ] ],
    [ "CCMountInfo", "structCCMountInfo.html", [
      [ "creationTime", "structCCMountInfo.html#a4823499e070dc3dc2d3357ac04751e40", null ],
      [ "userLogonType", "structCCMountInfo.html#a7ff71c0df6d5774973787163fe0878f0", null ],
      [ "serverName", "structCCMountInfo.html#a3f282e53df6ce8bee684bff65b862315", null ],
      [ "serverInfo", "structCCMountInfo.html#a575d5cdd4da56270319b34a4807acb7b", null ],
      [ "statistics", "structCCMountInfo.html#a9a40f84628c5345659f8aacbc129919b", null ]
    ] ],
    [ "ccGetMountInformationA", "group__mount__info.html#gaeea2d6d0c102d66a956b2b6ca8cb92e2", null ],
    [ "ccGetMountInformation", "group__mount__info.html#ga1505b1d06c2ec055023f1f1a0156f90c", null ]
];

==> YNQ-1.6.2_Linux_S_CP.zip: YNQ-1.6.2_Linux_S_CP/NQ Library Reference/html/group__mount__info.js <==
var group__mount__info =
[
    [ "User Logon Type", "group__user__logon__type.html", "group__user__logon__type" ],
    [ "Server Capabilities", "group__server__capabilities.html", "group__server__capabilities" ],
    [ "Signing Policy", "group__signing__policy.html", "group__signing__policy" ],
    [ "CCSStatistics", "structCCSStatistics.html", [
      [ "readAmount", "structCCSStatistics.html#aa6cd342446ae008b9e087a597ebafcd1", null ],
      [ "writeAmount", "structCCSStatistics.html#ae4f3e5f90cd4f5a4f78ef5f580f92c88", null ]
    ] ],
    [ "CCServerInfo", "structCCServerInfo.html", [
      [ "dialect", "structCCServerInfo.html#a0c6ea5c14c29944549e8dd222ee6412f", null ],
      [ "serverCapabilities", "structCCServerInfo.html#a12f4460a27c3e80924010b0c35de7bb7", null ],
      [ "ips", "structCCServerInfo.html#a99d713ac4500832a73f75bda8adfdbbc", null ],
      [ "numIps", "structCCServerInfo.html#adb11fee1ed0404b98451150dd0ef3da7", null ],
      [ "serverSigningPolicy", "structCCServerInfo.html#a482566f1f1569ff421052c8cdf831b71", null ]
    ] ],
    [ "CCMountInfoA", "structCCMountInfoA.html", [
      [ "creationTime", "structCCMountInfoA.html#ae3c19055292a905bbdf5133f09fe290c", null ],
      [ "userLogonType", "structCCMountInfoA.html#a2bfd1f0697d185286fa83063a782e5c6", null ],
      [ "serverName", "structCCMountInfoA.html#afe53a55e1d20c7df2b78eda275d16b5e", null ],
      [ "serverInfo", "structCCMountInfoA.html#a3d9999f6066e144079ecb9002ffa662b", null ],
      [ "statistics", "structCCMountInfoA.html#a79c8956fdd6940e32fe0bfa07a67c8fa", null ]
    ] ],
    [ "CCMountInfo", "structCCMountInfo.html", [
      [ "creationTime", "structCCMountInfo.html#a4823499e070dc3dc2d3357ac04751e40", null ],
      [ "userLogonType", "structCCMountInfo.html#a7ff71c0df6d5774973787163fe0878f0", null ],
      [ "serverName", "structCCMountInfo.html#a3f282e53df6ce8bee684bff65b862315", null ],
      [ "serverInfo", "structCCMountInfo.html#a575d5cdd4da56270319b34a4807acb7b", null ],
      [ "statistics", "structCCMountInfo.html#a9a40f84628c5345659f8aacbc129919b", null ]
    ] ],
    [ "ccGetMountInformationA", "group__mount__info.html#gaeea2d6d0c102d66a956b2b6ca8cb92e2", null ],
    [ "ccGetMountInformation", "group__mount__info.html#ga1505b1d06c2ec055023f1f1a0156f90c", null ]
];
